@@ -1,4 +1,5 @@
 package Net::Amazon::EC2::AvailabilityZone;
+$Net::Amazon::EC2::AvailabilityZone::VERSION = '0.35';
 use Moose;
 
 =head1 NAME
@@ -35,7 +36,7 @@ An array ref of Net::Amazon::EC2::AvailabilityZoneMessage objects representing m
 
 has 'zone_name'		=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'zone_state'	=> ( is => 'ro', isa => 'Str', required => 1 );
-has 'region_name'	=> ( is => 'ro', isa => 'Str', required => 1 );
+has 'region_name'	=> ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
 has 'messages'		=> ( is => 'ro', isa => 'ArrayRef[Net::Amazon::EC2::AvailabilityZoneMessage]|Undef', required => 0 );
 
 __PACKAGE__->meta->make_immutable();
