@@ -1,4 +1,5 @@
 package Net::Amazon::EC2::StateReason;
+$Net::Amazon::EC2::StateReason::VERSION = '0.35';
 use Moose;
 
 =head1 NAME
@@ -25,8 +26,8 @@ A message providing additional information about the state.
 
 =cut
 
-has 'code'		=> ( is => 'ro', isa => 'Int|Str' );
-has 'message' 	=> ( is => 'ro', isa => 'Str' );
+has 'code'		=> ( is => 'ro', isa => 'Maybe[Int|Str]' );
+has 'message' 	=> ( is => 'ro', isa => 'Maybe[Str]' );
 
 __PACKAGE__->meta->make_immutable();
 
@@ -42,4 +43,4 @@ under the same terms as Perl itself.
 =cut
 
 no Moose;
-1;
\ No newline at end of file
+1;
